@@ -17,6 +17,8 @@
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 
@@ -32,7 +34,7 @@ typedef enum {
    EN_F
 } enum_t;
 
-int main()
+int main(void)
 {
   /* libexif assumes unsigned ints are not smaller than 32bit in many places */
   assert(sizeof(unsigned int) >= sizeof(uint32_t));
